@@ -10,7 +10,7 @@
 # ABSTRACT: Check the configuration of an application
 
 package App::Cme::Command::check ;
-$App::Cme::Command::check::VERSION = '1.010';
+$App::Cme::Command::check::VERSION = '1.013';
 use strict;
 use warnings;
 use 5.10.1;
@@ -57,8 +57,10 @@ sub execute {
 
     my $ouch = $inst->has_warning;
 
-    if ( $opt->{strict} and $ouch ) {
-        die "Found $ouch warnings in strict mode\n";
+    if ( $ouch ) {
+        my $app = $inst->application;
+        warn "you can try 'cme fix $app' to fix the warnings shown above\n";
+        die "Found $ouch warnings in strict mode\n" if $opt->{strict};
     }
 }
 
@@ -76,7 +78,7 @@ App::Cme::Command::check - Check the configuration of an application
 
 =head1 VERSION
 
-version 1.010
+version 1.013
 
 =head1 SYNOPSIS
 
@@ -115,7 +117,8 @@ See L<cme/"Global Options">.
 
 =item -strict
 
-When set, cme will exit 1 if warnings are found during check (of left after fix)
+When set, cme exits 1 if warnings are found. By default, C<cme> exits
+0 when warnings are found.
 
 =back
 
@@ -123,7 +126,7 @@ When set, cme will exit 1 if warnings are found during check (of left after fix)
 
 cme exits 0 when no errors are found. Exit 1 otherwise.
 
-If C<-strict> option is set, cme will exit 1 when warnings are still present when the program ends.
+If C<-strict> option is set, cme exits 1 when warnings are found.
 
 =head1 SEE ALSO
 
